# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ManagedIdentityType',
    'RuntimeVersion',
    'UserSourceType',
]


class ManagedIdentityType(str, Enum):
    """
    Type of the managed identity
    """
    NONE = "None"
    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned,UserAssigned"


class RuntimeVersion(str, Enum):
    """
    Runtime version
    """
    JAVA_8 = "Java_8"
    JAVA_11 = "Java_11"
    NET_CORE_31 = "NetCore_31"


class UserSourceType(str, Enum):
    """
    Type of the source uploaded
    """
    JAR = "Jar"
    NET_CORE_ZIP = "NetCoreZip"
    SOURCE = "Source"
