# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .creator import *
from .get_account import *
from .get_creator import *
from .get_private_atlase import *
from .list_account_keys import *
from .private_atlase import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.maps.v20170101preview as __v20170101preview
    v20170101preview = __v20170101preview
    import pulumi_azure_native.maps.v20180501 as __v20180501
    v20180501 = __v20180501
    import pulumi_azure_native.maps.v20200201preview as __v20200201preview
    v20200201preview = __v20200201preview
    import pulumi_azure_native.maps.v20210201 as __v20210201
    v20210201 = __v20210201
    import pulumi_azure_native.maps.v20210701preview as __v20210701preview
    v20210701preview = __v20210701preview
else:
    v20170101preview = _utilities.lazy_import('pulumi_azure_native.maps.v20170101preview')
    v20180501 = _utilities.lazy_import('pulumi_azure_native.maps.v20180501')
    v20200201preview = _utilities.lazy_import('pulumi_azure_native.maps.v20200201preview')
    v20210201 = _utilities.lazy_import('pulumi_azure_native.maps.v20210201')
    v20210701preview = _utilities.lazy_import('pulumi_azure_native.maps.v20210701preview')

