# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetConsoleWithLocationResult',
    'AwaitableGetConsoleWithLocationResult',
    'get_console_with_location',
]

@pulumi.output_type
class GetConsoleWithLocationResult:
    """
    Cloud shell console
    """
    def __init__(__self__, properties=None):
        if properties and not isinstance(properties, dict):
            raise TypeError("Expected argument 'properties' to be a dict")
        pulumi.set(__self__, "properties", properties)

    @property
    @pulumi.getter
    def properties(self) -> 'outputs.ConsolePropertiesResponse':
        """
        Cloud shell console properties.
        """
        return pulumi.get(self, "properties")


class AwaitableGetConsoleWithLocationResult(GetConsoleWithLocationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConsoleWithLocationResult(
            properties=self.properties)


def get_console_with_location(console_name: Optional[str] = None,
                              location: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConsoleWithLocationResult:
    """
    Cloud shell console
    API Version: 2018-10-01.


    :param str console_name: The name of the console
    :param str location: The provider location
    """
    __args__ = dict()
    __args__['consoleName'] = console_name
    __args__['location'] = location
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure-native:portal:getConsoleWithLocation', __args__, opts=opts, typ=GetConsoleWithLocationResult).value

    return AwaitableGetConsoleWithLocationResult(
        properties=__ret__.properties)
