# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities

__all__ = [
    'GetVirtualMachineRdpFileContentsResult',
    'AwaitableGetVirtualMachineRdpFileContentsResult',
    'get_virtual_machine_rdp_file_contents',
]

@pulumi.output_type
class GetVirtualMachineRdpFileContentsResult:
    """
    Represents a .rdp file
    """
    def __init__(__self__, contents=None):
        if contents and not isinstance(contents, str):
            raise TypeError("Expected argument 'contents' to be a str")
        pulumi.set(__self__, "contents", contents)

    @property
    @pulumi.getter
    def contents(self) -> Optional[str]:
        """
        The contents of the .rdp file
        """
        return pulumi.get(self, "contents")


class AwaitableGetVirtualMachineRdpFileContentsResult(GetVirtualMachineRdpFileContentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVirtualMachineRdpFileContentsResult(
            contents=self.contents)


def get_virtual_machine_rdp_file_contents(lab_name: Optional[str] = None,
                                          name: Optional[str] = None,
                                          resource_group_name: Optional[str] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVirtualMachineRdpFileContentsResult:
    """
    Represents a .rdp file


    :param str lab_name: The name of the lab.
    :param str name: The name of the virtual machine.
    :param str resource_group_name: The name of the resource group.
    """
    __args__ = dict()
    __args__['labName'] = lab_name
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure-native:devtestlab/v20180915:getVirtualMachineRdpFileContents', __args__, opts=opts, typ=GetVirtualMachineRdpFileContentsResult).value

    return AwaitableGetVirtualMachineRdpFileContentsResult(
        contents=__ret__.contents)
