# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ApplicationArtifactType',
    'ApplicationLockLevel',
    'ResourceIdentityType',
]


class ApplicationArtifactType(str, Enum):
    """
    The managed application artifact type.
    """
    TEMPLATE = "Template"
    CUSTOM = "Custom"


class ApplicationLockLevel(str, Enum):
    """
    The managed application lock level.
    """
    CAN_NOT_DELETE = "CanNotDelete"
    READ_ONLY = "ReadOnly"
    NONE = "None"


class ResourceIdentityType(str, Enum):
    """
    The identity type.
    """
    SYSTEM_ASSIGNED = "SystemAssigned"
