# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ProbeProtocol',
    'Protocol',
]


class ProbeProtocol(str, Enum):
    """
    the reference to the load balancer probe used by the load balancing rule.
    """
    TCP = "tcp"
    HTTP = "http"
    HTTPS = "https"


class Protocol(str, Enum):
    """
    The reference to the transport protocol used by the load balancing rule.
    """
    TCP = "tcp"
    UDP = "udp"
